==> gimp-1.3.0.tar.bz2: gimp-1.3.0/app/tools/gimpbucketfilltool.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef  __GIMP_BUCKET_FILL_TOOL_H__
#define  __GIMP_BUCKET_FILL_TOOL_H__


#include "gimptool.h"


#define GIMP_TYPE_BUCKET_FILL_TOOL            (gimp_bucket_fill_tool_get_type ())
#define GIMP_BUCKET_FILL_TOOL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_BUCKET_FILL_TOOL, GimpBucketFillTool))
#define GIMP_BUCKET_FILL_TOOL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_BUCKET_FILL_TOOL, GimpBucketFillToolClass))
#define GIMP_IS_BUCKET_FILL_TOOL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_BUCKET_FILL_TOOL))
#define GIMP_IS_BUCKET_FILL_TOOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_BUCKET_FILL_TOOL))
#define GIMP_BUCKET_FILL_TOOL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_BUCKET_FILL_TOOL, GimpBucketFillToolClass))


typedef struct _GimpBucketFillTool      GimpBucketFillTool;
typedef struct _GimpBucketFillToolClass GimpBucketFillToolClass;

struct _GimpBucketFillTool
{
  GimpTool  parent_instance;

  gint      target_x;  /*  starting x coord  */
  gint      target_y;  /*  starting y coord  */
};

struct _GimpBucketFillToolClass
{
  GimpToolClass  parent_class;
};


void    gimp_bucket_fill_tool_register (Gimp *gimp);

GType   gimp_bucket_fill_tool_get_type (void);


#endif  /*  __GIMP_BUCKET_FILL_TOOL_H__  */

==> gimp-1.3.3.tar.bz2: gimp-1.3.3/app/tools/gimpbucketfilltool.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef  __GIMP_BUCKET_FILL_TOOL_H__
#define  __GIMP_BUCKET_FILL_TOOL_H__


#include "gimptool.h"


#define GIMP_TYPE_BUCKET_FILL_TOOL            (gimp_bucket_fill_tool_get_type ())
#define GIMP_BUCKET_FILL_TOOL(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_BUCKET_FILL_TOOL, GimpBucketFillTool))
#define GIMP_BUCKET_FILL_TOOL_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_BUCKET_FILL_TOOL, GimpBucketFillToolClass))
#define GIMP_IS_BUCKET_FILL_TOOL(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_BUCKET_FILL_TOOL))
#define GIMP_IS_BUCKET_FILL_TOOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_BUCKET_FILL_TOOL))
#define GIMP_BUCKET_FILL_TOOL_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_BUCKET_FILL_TOOL, GimpBucketFillToolClass))


typedef struct _GimpBucketFillTool      GimpBucketFillTool;
typedef struct _GimpBucketFillToolClass GimpBucketFillToolClass;

struct _GimpBucketFillTool
{
  GimpTool  parent_instance;

  gint      target_x;  /*  starting x coord  */
  gint      target_y;  /*  starting y coord  */
};

struct _GimpBucketFillToolClass
{
  GimpToolClass  parent_class;
};


void    gimp_bucket_fill_tool_register (Gimp                     *gimp,
                                        GimpToolRegisterCallback  callback);

GType   gimp_bucket_fill_tool_get_type (void) G_GNUC_CONST;


#endif  /*  __GIMP_BUCKET_FILL_TOOL_H__  */
